==> haskell-http-client-tls-0.3.6.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client-tls
version:              0.3.6.1
visibility:           public
id:                   http-client-tls-0.3.6.1-DFszg0yuulMCdj8fQt6z77
key:                  http-client-tls-0.3.6.1-DFszg0yuulMCdj8fQt6z77
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  ffac4c2829d1acd270915e02415c43ec
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.0.2/site-local/http-client-tls-0.3.6.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http-client-tls-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-tls
hs-libraries:         HShttp-client-tls-0.3.6.1-DFszg0yuulMCdj8fQt6z77
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-AmrqIhTD8km9mbo5tnh83Q
    connection-0.3.1-4daRpgKcfWr1vKE9mov1P3 containers-0.6.4.1
    cryptonite-0.30-3glVgFBweYyLIhWNiCMStp
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO exceptions-0.10.4
    http-client-0.7.11-ERqGdMYZts5H0jeKHXV1eF
    http-types-0.12.3-2bCY8ruZ9ekKCi90A515H
    memory-0.17.0-CJJwCTl3QuwCxlJovCa0Bf
    network-3.1.2.7-EuFNMFR0kXs1j7tEW9CoN1
    network-uri-2.6.4.1-4xrPI2Tj8np6ivptg0MZK4 text-1.2.5.0
    tls-1.5.7-5PJuI1rDMYR6zwJfUjS7UD transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.6.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client-tls
version:              0.3.6.1
visibility:           public
id:                   http-client-tls-0.3.6.1-DPB14PZhmrrCtq4JQNlcAq
key:                  http-client-tls-0.3.6.1-DPB14PZhmrrCtq4JQNlcAq
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  c4cc804df2557ad870a9661bc8926e02
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.0.2/site-local/http-client-tls-0.3.6.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/http-client-tls-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-tls
hs-libraries:         HShttp-client-tls-0.3.6.1-DPB14PZhmrrCtq4JQNlcAq
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-6h3hchaUNw8qyAgoXR952
    connection-0.3.1-70VMcqXkbZGD369H9k2ij8 containers-0.6.4.1
    cryptonite-0.30-8pbBStW4GxDLepPeY3vJC9
    data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO exceptions-0.10.4
    http-client-0.7.11-GDUAul739VNDIAAERjCbSI
    http-types-0.12.3-4jMePCcE8qw4JdYm3t2GC1
    memory-0.17.0-CJJwCTl3QuwCxlJovCa0Bf
    network-3.1.2.7-2cSl2Bow6uq3iMyh4pkAYO
    network-uri-2.6.4.1-1pF7wEplABcLvTQkIWYZHD text-1.2.5.0
    tls-1.5.7-8eiAf1uL8013MUVTh8kzn5 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
